Class: Google::Apis::PlaydeveloperreportingV1beta1::ApiservingMcpMcpToolVisibility
- Inherits:
-
Object
- Object
- Google::Apis::PlaydeveloperreportingV1beta1::ApiservingMcpMcpToolVisibility
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/playdeveloperreporting_v1beta1/classes.rb,
lib/google/apis/playdeveloperreporting_v1beta1/representations.rb,
lib/google/apis/playdeveloperreporting_v1beta1/representations.rb
Overview
Profile describing the visibility restriction of an MCP tool. Key: "google.com/ tool.profiles/visibility.restriction"
Instance Attribute Summary collapse
-
#field_visibility ⇒ Array<Google::Apis::PlaydeveloperreportingV1beta1::ApiservingMcpMcpToolVisibilityFieldVisibility>
A list of field-level visibility restrictions.
-
#visibility_enforcement_strategy ⇒ String
The strategy used to enforce visibility restrictions.
-
#visibility_restriction ⇒ String
The visibility restriction labels for the tool itself (e.g., " PRODUCER_DEFINED_PREVIEW").
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApiservingMcpMcpToolVisibility
constructor
A new instance of ApiservingMcpMcpToolVisibility.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApiservingMcpMcpToolVisibility
Returns a new instance of ApiservingMcpMcpToolVisibility.
48 49 50 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 48 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_visibility ⇒ Array<Google::Apis::PlaydeveloperreportingV1beta1::ApiservingMcpMcpToolVisibilityFieldVisibility>
A list of field-level visibility restrictions.
Corresponds to the JSON property fieldVisibility
33 34 35 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 33 def field_visibility @field_visibility end |
#visibility_enforcement_strategy ⇒ String
The strategy used to enforce visibility restrictions. DO NOT USE. This field
is not yet implemented.
Corresponds to the JSON property visibilityEnforcementStrategy
39 40 41 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 39 def visibility_enforcement_strategy @visibility_enforcement_strategy end |
#visibility_restriction ⇒ String
The visibility restriction labels for the tool itself (e.g., "
PRODUCER_DEFINED_PREVIEW"). Multiple labels can be provided as a comma-
separated string.
Corresponds to the JSON property visibilityRestriction
46 47 48 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 46 def visibility_restriction @visibility_restriction end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53 54 55 56 57 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 53 def update!(**args) @field_visibility = args[:field_visibility] if args.key?(:field_visibility) @visibility_enforcement_strategy = args[:visibility_enforcement_strategy] if args.key?(:visibility_enforcement_strategy) @visibility_restriction = args[:visibility_restriction] if args.key?(:visibility_restriction) end |