Class: Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1ErrorReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/playdeveloperreporting_v1beta1/classes.rb,
lib/google/apis/playdeveloperreporting_v1beta1/representations.rb,
lib/google/apis/playdeveloperreporting_v1beta1/representations.rb

Overview

An error report received for an app. There reports are produced by the Android platform code when a (potentially fatal) error condition is detected. Identical reports from many users will be deduplicated and coalesced into a single ErrorReport. Required permissions: to access this resource, the calling user needs the View app information (read-only) permission for the app.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePlayDeveloperReportingV1beta1ErrorReport

Returns a new instance of GooglePlayDeveloperReportingV1beta1ErrorReport.



767
768
769
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 767

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_versionGoogle::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1AppVersion

Representations of an app version. Corresponds to the JSON property appVersion



715
716
717
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 715

def app_version
  @app_version
end

#device_modelGoogle::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1DeviceModelSummary

Summary of a device Corresponds to the JSON property deviceModel



720
721
722
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 720

def device_model
  @device_model
end

#event_timeString

Start of the hour during which the latest event in this error report occurred. Corresponds to the JSON property eventTime

Returns:

  • (String)


725
726
727
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 725

def event_time
  @event_time
end

#issueString

The issue this report was associated with. Please note: this resource is currently in Alpha. There could be changes to the issue grouping that would result in similar but more recent error reports being assigned to a different issue. Corresponds to the JSON property issue

Returns:

  • (String)


733
734
735
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 733

def issue
  @issue
end

#nameString

Identifier. The resource name of the report. Format: apps/app/report Corresponds to the JSON property name

Returns:

  • (String)


738
739
740
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 738

def name
  @name
end

#os_versionGoogle::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1OsVersion

Representation of an OS version. Corresponds to the JSON property osVersion



743
744
745
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 743

def os_version
  @os_version
end

#report_textString

Textual representation of the error report. These textual reports are produced by the platform. The reports are then sanitized and filtered to remove any potentially sensitive information. Although their format is fairly stable, they are not entirely meant for machine consumption and we cannot guarantee that there won't be subtle changes to the formatting that may break systems trying to parse information out of the reports. Corresponds to the JSON property reportText

Returns:

  • (String)


753
754
755
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 753

def report_text
  @report_text
end

#typeString

Type of the error for which this report was generated. Corresponds to the JSON property type

Returns:

  • (String)


758
759
760
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 758

def type
  @type
end

#vcs_informationString

Version control system information from BUNDLE-METADATA/version-control-info. textproto or META-INF/version-control-info.textproto of the app bundle or APK, respectively. Corresponds to the JSON property vcsInformation

Returns:

  • (String)


765
766
767
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 765

def vcs_information
  @vcs_information
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



772
773
774
775
776
777
778
779
780
781
782
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 772

def update!(**args)
  @app_version = args[:app_version] if args.key?(:app_version)
  @device_model = args[:device_model] if args.key?(:device_model)
  @event_time = args[:event_time] if args.key?(:event_time)
  @issue = args[:issue] if args.key?(:issue)
  @name = args[:name] if args.key?(:name)
  @os_version = args[:os_version] if args.key?(:os_version)
  @report_text = args[:report_text] if args.key?(:report_text)
  @type = args[:type] if args.key?(:type)
  @vcs_information = args[:vcs_information] if args.key?(:vcs_information)
end