Class: Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1MetricsRow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/playdeveloperreporting_v1beta1/classes.rb,
lib/google/apis/playdeveloperreporting_v1beta1/representations.rb,
lib/google/apis/playdeveloperreporting_v1beta1/representations.rb

Overview

Represents a row of dimensions and metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GooglePlayDeveloperReportingV1beta1MetricsRow

Returns a new instance of GooglePlayDeveloperReportingV1beta1MetricsRow.



1266
1267
1268
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 1266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_periodString

Optional. Granularity of the aggregation period of the row. Corresponds to the JSON property aggregationPeriod

Returns:

  • (String)


1236
1237
1238
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 1236

def aggregation_period
  @aggregation_period
end

#dimensionsArray<Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1DimensionValue>

Optional. Dimension columns in the row. Corresponds to the JSON property dimensions



1241
1242
1243
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 1241

def dimensions
  @dimensions
end

#metricsArray<Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1MetricValue>

Optional. Metric columns in the row. Corresponds to the JSON property metrics



1246
1247
1248
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 1246

def metrics
  @metrics
end

#start_timeGoogle::Apis::PlaydeveloperreportingV1beta1::GoogleTypeDateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property startTime



1264
1265
1266
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 1264

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1271
1272
1273
1274
1275
1276
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 1271

def update!(**args)
  @aggregation_period = args[:aggregation_period] if args.key?(:aggregation_period)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @metrics = args[:metrics] if args.key?(:metrics)
  @start_time = args[:start_time] if args.key?(:start_time)
end