Class: Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1SlowStartRateMetricSet
- Inherits:
-
Object
- Object
- Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1SlowStartRateMetricSet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/playdeveloperreporting_v1beta1/classes.rb,
lib/google/apis/playdeveloperreporting_v1beta1/representations.rb,
lib/google/apis/playdeveloperreporting_v1beta1/representations.rb
Overview
Singleton resource representing the set of Slow Start metrics. This metric set
contains Activity start duration data. Supported aggregation periods: *
DAILY: metrics are aggregated in calendar date intervals. Due to historical
constraints, the only supported timezone is America/Los_Angeles. Supported
metrics: * slowStartRate (google.type.Decimal): Percentage of distinct
users in the aggregation period that had a slow start. *
slowStartRate7dUserWeighted (google.type.Decimal): Rolling average value of
slowStartRate in the last 7 days. The daily values are weighted by the count
of distinct users for the day. * slowStartRate28dUserWeighted (google.type.
Decimal): Rolling average value of slowStartRate in the last 28 days. The
daily values are weighted by the count of distinct users for the day. *
distinctUsers (google.type.Decimal): Count of distinct users in the
aggregation period that were used as normalization value for the
slowStartRate metric. A user is counted in this metric if their app was
launched in the device. Care must be taken not to aggregate this count further,
as it may result in users being counted multiple times. The value is rounded
to the nearest multiple of 10, 100, 1,000 or 1,000,000, depending on the
magnitude of the value. Required dimension: This dimension must be
specified with each request for the request to be valid. * startType (string)
: the type of start that was measured. Valid types are HOT, WARM and COLD
. Supported dimensions: * apiLevel (string): the API level of Android
that was running on the user's device, e.g., 26. * versionCode (int64):
version of the app that was running on the user's device. * deviceModel (
string): unique identifier of the user's device model. The form of the
identifier is 'deviceBrand/device', where deviceBrand corresponds to Build.
BRAND and device corresponds to Build.DEVICE, e.g., google/coral. *
deviceBrand (string): unique identifier of the user's device brand, e.g.,
google. * deviceType (string): the type (also known as form factor) of the
user's device, e.g., PHONE. * countryCode (string): the country or region of
the user's device based on their IP address, represented as a 2-letter ISO-
3166 code (e.g. US for the United States). * deviceRamBucket (int64): RAM of
the device, in MB, in buckets (e.g., 1024 for 1-1.5GB, 4096 for 4-6GB). *
deviceSocMake (string): Make of the device's primary system-on-chip, e.g.,
Samsung. Reference * deviceSocModel (string): Model of the device's primary
system-on-chip, e.g., "Exynos 2100". Reference * deviceCpuMake (string): Make of the
device's CPU, e.g., Qualcomm. * deviceCpuModel (string): Model of the device'
s CPU, e.g., "Kryo 240". * deviceGpuMake (string): Make of the device's GPU,
e.g., ARM. * deviceGpuModel (string): Model of the device's GPU, e.g., Mali.
deviceGpuVersion(string): Version of the device's GPU, e.g., T750. *deviceVulkanVersion(string): Vulkan version of the device, e.g., "4198400". *deviceGlEsVersion(string): OpenGL ES version of the device, e.g., "196610".deviceScreenSize(string): Screen size of the device, e.g., NORMAL, LARGE.deviceScreenDpi(string): Screen density of the device, e.g., mdpi, hdpi. Required permissions: to access this resource, the calling user needs the View app information (read-only) permission for the app.
Instance Attribute Summary collapse
-
#freshness_info ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1FreshnessInfo
Represents the latest available time that can be requested in a TimelineSpec.
-
#name ⇒ String
Identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePlayDeveloperReportingV1beta1SlowStartRateMetricSet
constructor
A new instance of GooglePlayDeveloperReportingV1beta1SlowStartRateMetricSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePlayDeveloperReportingV1beta1SlowStartRateMetricSet
Returns a new instance of GooglePlayDeveloperReportingV1beta1SlowStartRateMetricSet.
2982 2983 2984 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 2982 def initialize(**args) update!(**args) end |
Instance Attribute Details
#freshness_info ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1FreshnessInfo
Represents the latest available time that can be requested in a TimelineSpec.
Different aggregation periods have different freshness. For example, DAILY
aggregation may lag behind HOURLY in cases where such aggregation is
computed only once at the end of the day.
Corresponds to the JSON property freshnessInfo
2975 2976 2977 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 2975 def freshness_info @freshness_info end |
#name ⇒ String
Identifier. The resource name. Format: apps/app/slowStartRateMetricSet
Corresponds to the JSON property name
2980 2981 2982 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 2980 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2987 2988 2989 2990 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 2987 def update!(**args) @freshness_info = args[:freshness_info] if args.key?(:freshness_info) @name = args[:name] if args.key?(:name) end |