Class: Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1ErrorIssue
- Inherits:
-
Object
- Object
- Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1ErrorIssue
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/playdeveloperreporting_v1beta1/classes.rb,
lib/google/apis/playdeveloperreporting_v1beta1/representations.rb,
lib/google/apis/playdeveloperreporting_v1beta1/representations.rb
Overview
A group of related ErrorReports received for an app. Similar error reports are grouped together into issues with a likely identical root cause. Please note: ** this resource is currently in Alpha. There could be changes to the issue grouping that would result in similar but more recent error reports being assigned to different issues. This could also cause some issues disappearing entirely and being replaced by new ones. **Required permissions: to access this resource, the calling user needs the View app information (read-only) permission for the app.
Instance Attribute Summary collapse
-
#annotations ⇒ Array<Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1IssueAnnotation>
List of annotations for an issue.
-
#cause ⇒ String
Cause of the issue.
-
#distinct_users ⇒ Fixnum
An estimate of the number of unique users who have experienced this issue ( only considering occurrences matching the filters and within the requested time period).
-
#distinct_users_percent ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GoogleTypeDecimal
A representation of a decimal value, such as 2.5.
-
#error_report_count ⇒ Fixnum
The total number of error reports in this issue (only considering occurrences matching the filters and within the requested time period).
-
#first_app_version ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1AppVersion
Representations of an app version.
-
#first_os_version ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1OsVersion
Representation of an OS version.
-
#issue_uri ⇒ String
Link to the issue in Android vitals in the Play Console.
-
#last_app_version ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1AppVersion
Representations of an app version.
-
#last_error_report_time ⇒ String
Start of the hour during which the last error report in this issue occurred.
-
#last_os_version ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1OsVersion
Representation of an OS version.
-
#location ⇒ String
Location where the issue happened.
-
#name ⇒ String
Identifier.
-
#sample_error_reports ⇒ Array<String>
Output only.
-
#type ⇒ String
Type of the errors grouped in this issue.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GooglePlayDeveloperReportingV1beta1ErrorIssue
constructor
A new instance of GooglePlayDeveloperReportingV1beta1ErrorIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GooglePlayDeveloperReportingV1beta1ErrorIssue
Returns a new instance of GooglePlayDeveloperReportingV1beta1ErrorIssue.
679 680 681 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Array<Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1IssueAnnotation>
List of annotations for an issue. Annotations provide additional information
that may help in diagnosing and fixing the issue.
Corresponds to the JSON property annotations
593 594 595 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 593 def annotations @annotations end |
#cause ⇒ String
Cause of the issue. Depending on the type this can be either: *
APPLICATION_NOT_RESPONDING: the type of ANR that occurred, e.g., 'Input
dispatching timed out'. * CRASH: for Java unhandled exception errors, the type
of the innermost exception that was thrown, e.g., IllegalArgumentException.
For signals in native code, the signal that was raised, e.g. SIGSEGV.
Corresponds to the JSON property cause
602 603 604 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 602 def cause @cause end |
#distinct_users ⇒ Fixnum
An estimate of the number of unique users who have experienced this issue (
only considering occurrences matching the filters and within the requested
time period).
Corresponds to the JSON property distinctUsers
609 610 611 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 609 def distinct_users @distinct_users end |
#distinct_users_percent ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GoogleTypeDecimal
A representation of a decimal value, such as 2.5. Clients may convert values
into language-native decimal formats, such as Java's BigDecimal or
Python's decimal.Decimal.
Corresponds to the JSON property distinctUsersPercent
617 618 619 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 617 def distinct_users_percent @distinct_users_percent end |
#error_report_count ⇒ Fixnum
The total number of error reports in this issue (only considering occurrences
matching the filters and within the requested time period).
Corresponds to the JSON property errorReportCount
623 624 625 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 623 def error_report_count @error_report_count end |
#first_app_version ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1AppVersion
Representations of an app version.
Corresponds to the JSON property firstAppVersion
628 629 630 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 628 def first_app_version @first_app_version end |
#first_os_version ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1OsVersion
Representation of an OS version.
Corresponds to the JSON property firstOsVersion
633 634 635 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 633 def first_os_version @first_os_version end |
#issue_uri ⇒ String
Link to the issue in Android vitals in the Play Console.
Corresponds to the JSON property issueUri
638 639 640 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 638 def issue_uri @issue_uri end |
#last_app_version ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1AppVersion
Representations of an app version.
Corresponds to the JSON property lastAppVersion
643 644 645 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 643 def last_app_version @last_app_version end |
#last_error_report_time ⇒ String
Start of the hour during which the last error report in this issue occurred.
Corresponds to the JSON property lastErrorReportTime
648 649 650 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 648 def last_error_report_time @last_error_report_time end |
#last_os_version ⇒ Google::Apis::PlaydeveloperreportingV1beta1::GooglePlayDeveloperReportingV1beta1OsVersion
Representation of an OS version.
Corresponds to the JSON property lastOsVersion
653 654 655 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 653 def last_os_version @last_os_version end |
#location ⇒ String
Location where the issue happened. Depending on the type this can be either: *
APPLICATION_NOT_RESPONDING: the name of the activity or service that stopped
responding. * CRASH: the likely method name that caused the error.
Corresponds to the JSON property location
660 661 662 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 660 def location @location end |
#name ⇒ String
Identifier. The resource name of the issue. Format: apps/app/issue
Corresponds to the JSON property name
665 666 667 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 665 def name @name end |
#sample_error_reports ⇒ Array<String>
Output only. Sample error reports which belong to this ErrorIssue. Note:
currently a maximum of 1 per ErrorIssue is supported. Format: "apps/app/
report"
Corresponds to the JSON property sampleErrorReports
672 673 674 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 672 def sample_error_reports @sample_error_reports end |
#type ⇒ String
Type of the errors grouped in this issue.
Corresponds to the JSON property type
677 678 679 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 677 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 |
# File 'lib/google/apis/playdeveloperreporting_v1beta1/classes.rb', line 684 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @cause = args[:cause] if args.key?(:cause) @distinct_users = args[:distinct_users] if args.key?(:distinct_users) @distinct_users_percent = args[:distinct_users_percent] if args.key?(:distinct_users_percent) @error_report_count = args[:error_report_count] if args.key?(:error_report_count) @first_app_version = args[:first_app_version] if args.key?(:first_app_version) @first_os_version = args[:first_os_version] if args.key?(:first_os_version) @issue_uri = args[:issue_uri] if args.key?(:issue_uri) @last_app_version = args[:last_app_version] if args.key?(:last_app_version) @last_error_report_time = args[:last_error_report_time] if args.key?(:last_error_report_time) @last_os_version = args[:last_os_version] if args.key?(:last_os_version) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @sample_error_reports = args[:sample_error_reports] if args.key?(:sample_error_reports) @type = args[:type] if args.key?(:type) end |